package com.timtech.profile.dto;

import java.io.Serializable;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import javax.validation.constraints.Pattern;
import javax.validation.constraints.Size;

import lombok.AllArgsConstructor;
import lombok.Builder;
import lombok.Data;
import lombok.NoArgsConstructor;

@Data
@Builder
@AllArgsConstructor
@NoArgsConstructor
public class ProfileDto implements Serializable {
	
	private static final long serialVersionUID = 1L;
	
	@NotNull(message = "Id must not be null", groups = ProfileUpdate.class)
	private String profileId;
	
	@NotNull(message = "First Name is Mandatory")
	@Pattern(regexp = "^[a-zA-Z]+$", message = "First Name should only contain alphabets and spaces")
	private String firstName;
	
	@NotNull(message = "Last Name is Mandatory")
	@Pattern(regexp = "^[a-zA-Z]+$", message = "Last Name should only contain alphabets and spaces")
	private String lastName;
	
    @NotNull(message = "Date of Birth is Mandatory")
    @Pattern(regexp = "^\\d{2}-\\d{2}-\\d{4}$", message = "Date of Birth should be in MM-DD-YYYY format")
    private String dateOfBirth;
	
//    @Pattern(regexp = "^[A-Z]{5}\\d{4}[A-Z]$", message = "Invalid PAN format")
    @Pattern(regexp = "[A-Z]{5}[0-9]{4}[A-Z]{1}", message = "Invalid PAN format")
    private String permanentAccountNumber;
	
    @Size(min = 12, max = 12, message = "Aadhar Number should be a 12-digit number")
   // @Pattern(regexp = "^[1-9]\\d{11}$", message = "Aadhar Number should not start with 0")
    @Pattern(regexp = "^[2-9]\\d{1}[0-9]\\d{10}$", message = "Aadhar Number should not start with 0")
    private String adharNumber;
	
	@NotBlank(message = "Mobile Number is mandatory")
	@Pattern(regexp = "^[6-9]\\d{9}$", message = "Mobile Number should be 10-digit number starting with 6/7/8/9")
	private String mobileNumber;
	private String status;
	
	public interface ProfileCreate{}
	public interface ProfileUpdate{}
	
}



